# ARROWHEAD CLIENT PYTHON LIBRARY
This is a library for the creation of client service providers and consumer for the [Arrowhead Framework](www.arrowhead.eu), a service-oriented framework developed for industrial automation.
To read more about the library, please go to the [documentation](https://arrowhead-client-python-library.readthedocs.io/en/latest/).

## About
The Arrowhead Client Python Library is a library to make it easy to create your own Arrowhead Framework systems and services in Python.
This library provides interfaces to connect Python with the [Arrowhead Core Systems](https://github.com/arrowhead-f/core-java-spring).

### Development status
This library is still in the Alpha stage of development, this means that the APIs haven't yet matured and may change at any time.

The library currently supports the http and websockets protocols for service consumption.

The library only provides interfaces for he mandatory core systems at the moment, but inferfaces for the other core systems is planned.

### External Depencies
To run an Arrowhead system you need to have the Arrowhead core systems up and running, and the correct certificates need to be provided.
A guide on how to create your own certificates can be found on the [Arrowhead github](https://github.com/arrowhead-f/core-java-spring/blob/master/documentation/certificates/create_client_certificate.pdf).

## How To Use
See the [quickstart guide](https://arrowhead-client-python-library.readthedocs.io/en/latest/quickstart.html).

